# 31. Собственные векторы, собственные значения.

Пусть A – действительная числовая квадратная матрица размером (). Ненулевой вектор размером (), удовлетворяющий условию

называется собственным вектором матрицы . Число в равенстве называется собственным значением. Говорят, что собственный вектор соответствует (принадлежит) собственному значению .

Последнее равенство равносильно однородной относительно системе:

Система имеет ненулевое решение для вектора (при известном ) при условии . Это равенство есть характеристическое уравнение:

.

где – характеристический многочлен -й степени.

Корни характеристического уравнения являются собственными (характеристическими) значениями матрицы , а соответствующие каждому собственному значению , ненулевые векторы , удовлетворяющие системе , являются собственными векторами.

Задача линейной алгебры состоит в нахождении собственных значений и собственных векторов заданной матрицы.